@@ -10,7 +10,7 @@ class asciii():
         '$@B%8&WM#*oahkbdpqwmZO0QLCJUYXzcvunxrjft/\|()1{}[]?-_+~i!lI;:,\"^`". ',
         "@%#*+=-:. "
     ]
-    im_map=""
+    im_map=[]
 
     def __init__(self,pattern=0,max_size=0,shift=0):
         if isinstance(pattern,str):
@@ -61,10 +61,10 @@ class asciii():
                     if self.cols=="":
                         self.im_map+=f"\033[48;2;{r};{g};{b}m{''} \033[0m"
                     else:
-                        self.im_map+=self.cols[s]
-                self.im_map+="\n"
+                        self.im_map.append(self.cols[s])
+                self.im_map.append("\n")
                 #self.im_map=""
-        imap=self.im_map
+        imap="".join(self.im_map)
         self.im_map=""
         return imap
 
